==> libreoffice-fresh-sdk-25.2.4-2-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1SetExpression.js <==
var servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1SetExpression =
[
    [ "DependentTextField", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1SetExpression.html#ad9e399bc7074c22e5069ac12b2162aa1", null ],
    [ "Content", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1SetExpression.html#a6d1fb265b40351e94f79e0f749e5daf9", null ],
    [ "CurrentPresentation", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1SetExpression.html#a632a1788f5e2e009b3809bbb266e39a0", null ],
    [ "Hint", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1SetExpression.html#a0ad052e922e0eaa01eadc1db1d0776c3", null ],
    [ "IsFixedLanguage", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1SetExpression.html#a6d2a6e8913ac03867d5217d922acbaa7", null ],
    [ "IsInput", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1SetExpression.html#a3f9289ee5af1a58ae85cea250787a7b4", null ],
    [ "IsShowFormula", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1SetExpression.html#a8842056795da89e3aedc71027a3eaac0", null ],
    [ "IsVisible", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1SetExpression.html#a9a886e02e55d4f1dbabbb84da0ae7e7f", null ],
    [ "NumberFormat", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1SetExpression.html#a47bcb1c1fb4b08615d0866e989fd6f87", null ],
    [ "NumberingType", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1SetExpression.html#ae3dc42096fd541eb9a8b3c3e0654582b", null ],
    [ "SequenceValue", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1SetExpression.html#ad086dbbedcf7109ec3bd63fdbba04622", null ],
    [ "SubType", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1SetExpression.html#a5bad661412b99ded4eb8b8af067b398a", null ],
    [ "Value", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1SetExpression.html#a7b7e5af44fffe84c91c63ba0781ffdb3", null ],
    [ "VariableName", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1SetExpression.html#a315cf1cd90cad29a9c492c6adaa53c32", null ]
];

==> libreoffice-fresh-sdk-25.8.4-2-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1SetExpression.js <==
var servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1SetExpression =
[
    [ "com::sun::star::text::DependentTextField", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1SetExpression.html#ad9e399bc7074c22e5069ac12b2162aa1", null ],
    [ "Content", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1SetExpression.html#a6d1fb265b40351e94f79e0f749e5daf9", null ],
    [ "CurrentPresentation", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1SetExpression.html#a632a1788f5e2e009b3809bbb266e39a0", null ],
    [ "Hint", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1SetExpression.html#a0ad052e922e0eaa01eadc1db1d0776c3", null ],
    [ "IsFixedLanguage", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1SetExpression.html#a6d2a6e8913ac03867d5217d922acbaa7", null ],
    [ "IsInput", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1SetExpression.html#a3f9289ee5af1a58ae85cea250787a7b4", null ],
    [ "IsShowFormula", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1SetExpression.html#a8842056795da89e3aedc71027a3eaac0", null ],
    [ "IsVisible", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1SetExpression.html#a9a886e02e55d4f1dbabbb84da0ae7e7f", null ],
    [ "NumberFormat", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1SetExpression.html#a47bcb1c1fb4b08615d0866e989fd6f87", null ],
    [ "NumberingType", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1SetExpression.html#ae3dc42096fd541eb9a8b3c3e0654582b", null ],
    [ "SequenceValue", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1SetExpression.html#ad086dbbedcf7109ec3bd63fdbba04622", null ],
    [ "SubType", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1SetExpression.html#a5bad661412b99ded4eb8b8af067b398a", null ],
    [ "Value", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1SetExpression.html#a7b7e5af44fffe84c91c63ba0781ffdb3", null ],
    [ "VariableName", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1SetExpression.html#a315cf1cd90cad29a9c492c6adaa53c32", null ]
];
